@@ -1,6 +1,6 @@
 package CGI::Session::MySQL;
 
-# $Id: MySQL.pm,v 3.2 2002/11/27 12:26:03 sherzodr Exp $
+# $Id: MySQL.pm,v 3.2.4.1 2003/03/09 11:25:28 sherzodr Exp $
 
 use strict;
 # Inheriting necessary functionalities from the 
@@ -17,7 +17,7 @@ use base qw(
 
 use vars qw($VERSION $TABLE_NAME);
 
-($VERSION) = '$Revision: 3.2 $' =~ m/Revision:\s*(\S+)/;
+($VERSION) = '$Revision: 3.2.4.1 $' =~ m/Revision:\s*(\S+)/;
 
 $TABLE_NAME = 'sessions';
 
@@ -144,7 +144,7 @@ sub MySQL_dbh {
 
 
 
-# $Id: MySQL.pm,v 3.2 2002/11/27 12:26:03 sherzodr Exp $
+# $Id: MySQL.pm,v 3.2.4.1 2003/03/09 11:25:28 sherzodr Exp $
 
 1;       
 =pod
@@ -172,7 +172,7 @@ To store session data in MySQL database, you first need to create a suitable tab
 with the following command:
 
     CREATE TABLE sessions (
-        id CHAR(32) NOT NULL,
+        id CHAR(32) NOT NULL UNIQUE,
         a_session TEXT NOT NULL
     );
 
@@ -184,7 +184,7 @@ If you want to store the session data in other table than "sessions", before cre
 the session object you need to set the special variable B<$CGI::Session::MySQL::TABLE_NAME>
 to the name of the table:
 
-    use CGI::Session qw/-api3/;
+    use CGI::Session;
 
     $CGI::Session::MySQL::TABLE_NAME = 'my_sessions';
     $session = new CGI::Session("driver:MySQL", undef, {Handle=>$dbh});
@@ -236,4 +236,4 @@ L<Apache::Session|Apache::Session> - another fine alternative to CGI::Session
 
 
 
-# $Id: MySQL.pm,v 3.2 2002/11/27 12:26:03 sherzodr Exp $
+# $Id: MySQL.pm,v 3.2.4.1 2003/03/09 11:25:28 sherzodr Exp $
